@@ -1,6 +1,5 @@
 # TextDiversity pkgs
 import spacy
-import torch
 import numpy as np
 from sklearn.decomposition import PCA
 
@@ -10,16 +9,9 @@ from Bio import Align
 from ..metric import TextDiversity
 from ..utils import *
 
-# ==================================================================================
-# helper functions 
 # ==================================================================================
 
-def align_and_score(seq1, seq2):
-    return Align.PairwiseAligner().align(seq1, seq2).score
-
-# ==================================================================================
-
-class POSSequenceDiversity(TextDiversity):
+class PartOfSpeechSequence(TextDiversity):
 
     default_config = {
         # TextDiversity configs
@@ -28,28 +20,40 @@ class POSSequenceDiversity(TextDiversity):
         'dim_reducer': PCA,
         'remove_stopwords': False, 
         'verbose': False,
-        # POSSequenceDiversity configs
+        # PartOfSpeechSequence configs
         'pad_to_max_len': False, 
         'use_gpu': False,
-        'n_components': None 
+        'n_components': None,
+        'split_sentences': False,
     }
 
     def __init__(self, config={}):
         config = {**self.default_config, **config} 
         super().__init__(config)
         self.model = spacy.load("en_core_web_sm")
+        self.aligner = Align.PairwiseAligner()
 
-    def extract_features(self, corpus):
+    def align_and_score(self, seq1, seq2):
+        return self.aligner.align(seq1, seq2).score
+
+    def extract_features(self, corpus, return_ids=False):
 
         # clean corpus
         corpus = clean_text(corpus)
 
         # split sentences
-        sentences = split_sentences(corpus)
+        if self.config['split_sentences']:
+            corpus, text_ids, sentence_ids = split_sentences(corpus, return_ids=True)
+        else:
+            ids = list(range(len(corpus)))
+            text_ids, sentence_ids = ids, ids
+
+        # # remove any blanks...
+        # corpus = [d for d in corpus if len(d.strip()) > 0]
 
         # extracts parts-of-speech (poses)
         poses = []
-        for s in sentences:
+        for s in corpus:
             pos = [token.pos_ for token in self.model(s)] #if token.text not in stopwords]
             poses.append(pos)
 
@@ -60,7 +64,9 @@ class POSSequenceDiversity(TextDiversity):
         if self.config['pad_to_max_len']:
             poses = np.array([s + ['NULL'] * (self.max_len - len(s)) for s in poses])
 
-        return poses, sentences
+        if return_ids:
+            return poses, corpus, text_ids, sentence_ids 
+        return poses, corpus
 
     def calculate_similarities(self, features):
         """
@@ -74,9 +80,9 @@ class POSSequenceDiversity(TextDiversity):
             features = ["".join(pos) for pos in features]
 
         # compute pairwise alignment + scoring
-        Z = compute_pairwise(
+        Z = compute_Z_pairwise(
             features, 
-            align_and_score, 
+            self.align_and_score, 
             self.max_len, 
             verbose=self.config['verbose'])
 
@@ -87,7 +93,7 @@ class POSSequenceDiversity(TextDiversity):
 
     def calculate_similarity_vector(self, q_feat, c_feat):
 
-        features = q_feat + c_feat
+        features = [q_feat] + c_feat
 
         if is_list_of_lists(features):
             # convert pos tags to alphas
@@ -100,7 +106,7 @@ class POSSequenceDiversity(TextDiversity):
         q_len = len(q_feat)
         scores = []
         for f in c_feat:
-            score = align_and_score(q_feat, f)
+            score = self.align_and_score(q_feat, f)
             score /= max(len(f), q_len)
             scores.append(score)
 
@@ -125,14 +131,14 @@ if __name__ == '__main__':
 
     # diversities
     print("diversities")
-    print_div_metric(POSSequenceDiversity, lo_div, hi_div)
+    print_div_metric(PartOfSpeechSequence, lo_div, hi_div)
 
     # similarities
     print("similarities")
-    print_sim_metric(POSSequenceDiversity, lo_div, hi_div)
+    print_sim_metric(PartOfSpeechSequence, lo_div, hi_div)
 
     # rank similarities
     print("rankings")
-    print_ranking(POSSequenceDiversity, ["I was wrong"], lo_div + hi_div)
+    print_ranking(PartOfSpeechSequence, ["I was wrong"], lo_div + hi_div)
 
     # (textdiv) ~\GitHub\TextDiversity\src>python -m textdiversity.text_diversities.morphological
\ No newline at end of file
