@@ -1,9 +1,7 @@
 # TextDiversity pkgs
 import spacy
-import torch
 import numpy as np
 import pandas as pd
-import itertools
 from functools import partial
 import logging
 logging.basicConfig(level=logging.CRITICAL)
@@ -28,16 +26,9 @@ from collections import Counter
 from ..metric import TextDiversity
 from ..utils import *
 
-# ==================================================================================
-# helper functions 
 # ==================================================================================
 
-def align_and_score(seq1, seq2):
-    return Align.PairwiseAligner().align(seq1, seq2).score
-
-# ==================================================================================
-
-class RhythmicDiversity(TextDiversity):
+class Rhythmic(TextDiversity):
 
     default_config = {
         # TextDiversity configs
@@ -45,31 +36,41 @@ class RhythmicDiversity(TextDiversity):
         'normalize': False,
         'remove_stopwords': False, 
         'verbose': False,
-        # RhythmicDiversity configs
-        'pad_to_max_len': False
+        # Rhythmic configs
+        'pad_to_max_len': False,
+        'split_sentences': False,
     }
 
     def __init__(self, config={}):
         config = {**self.default_config, **config} 
         super().__init__(config)
         self.model = spacy.load("en_core_web_sm")
+        self.aligner = Align.PairwiseAligner()
 
-    def extract_features(self, corpus):
+    def align_and_score(self, seq1, seq2):
+        return self.aligner.align(seq1, seq2).score
+
+    def extract_features(self, corpus, return_ids=False):
 
         # clean corpus
         corpus = clean_text(corpus)
 
         # split sentences
-        sentences = split_sentences(corpus)
+        if self.config['split_sentences']:
+            corpus, text_ids, sentence_ids = split_sentences(corpus, return_ids=True)
+        else:
+            ids = list(range(len(corpus)))
+            text_ids, sentence_ids = ids, ids
 
         # strip punctuation
-        sentences = [s.translate(str.maketrans('', '', string.punctuation)) for s in sentences]
+        corpus = [d.translate(str.maketrans('', '', string.punctuation)) for d in corpus]
+
+        # # remove any blanks...
+        # corpus = [d for d in corpus if len(d.strip()) > 0]
 
         # extracts rhythms (sequences of [un]weighted [un]stressed syllables)
         rhythms = []
-        for s in sentences:
-            if len(s.strip()) == 0:
-                continue
+        for s in corpus:
             prose = cd.Prose(s)
             df = prose.sylls().reset_index()
             if all([c in df.columns for c in ['syll_stress', 'syll_weight']]):
@@ -86,7 +87,9 @@ class RhythmicDiversity(TextDiversity):
         if self.config['pad_to_max_len']:
             rhythms = np.array([r + ['N'] * (self.max_len - len(r)) for r in rhythms])
 
-        return rhythms, sentences
+        if return_ids:
+            return rhythms, corpus, text_ids, sentence_ids 
+        return rhythms, corpus
 
     def calculate_similarities(self, features):
         """
@@ -100,9 +103,9 @@ class RhythmicDiversity(TextDiversity):
             features = ["".join(rhythm) for rhythm in features]
 
         # compute pairwise alignment + scoring
-        Z = compute_pairwise(
+        Z = compute_Z_pairwise(
             features, 
-            align_and_score, 
+            self.align_and_score, 
             self.max_len, 
             verbose=self.config['verbose'])
 
@@ -114,7 +117,7 @@ class RhythmicDiversity(TextDiversity):
 
     def calculate_similarity_vector(self, q_feat, c_feat):
 
-        features = q_feat + c_feat
+        features = [q_feat] + c_feat
 
         if is_list_of_lists(features):
             # convert rhythm tags to alphas
@@ -127,7 +130,7 @@ class RhythmicDiversity(TextDiversity):
         q_len = len(q_feat)
         scores = []
         for f in c_feat:
-            score = align_and_score(q_feat, f)
+            score = self.align_and_score(q_feat, f)
             score /= max(len(f), q_len)
             scores.append(score)
 
@@ -144,9 +147,7 @@ class RhythmicDiversity(TextDiversity):
         return super().__call__(corpus)
 
 
-
-
-class PhonemicDiversity(TextDiversity):
+class Phonemic(TextDiversity):
 
     default_config = {
         # TextDiversity configs
@@ -214,7 +215,7 @@ class PhonemicDiversity(TextDiversity):
         return Z
 
     def calculate_similarity_vector(self, q_feat, c_feat):
-        raise Exception("Ranking requires metrics that operate on the document level. Try RhythmicDiversity instead.")
+        raise Exception("Ranking requires metrics that operate on the document level. Try Rhythmic instead.")
 
     def calculate_abundance(self, species):
         p = np.array(list(species.values()), dtype=np.float16)
@@ -233,17 +234,17 @@ if __name__ == '__main__':
 
     # diversities
     print("diversities")
-    print_div_metric(RhythmicDiversity, lo_div, hi_div)
-    print_div_metric(PhonemicDiversity, lo_div, hi_div)
+    print_div_metric(Rhythmic, lo_div, hi_div)
+    print_div_metric(Phonemic, lo_div, hi_div)
 
     # similarities
     print("similarities")
-    print_sim_metric(RhythmicDiversity, lo_div, hi_div)
-    print_sim_metric(PhonemicDiversity, lo_div, hi_div)
+    print_sim_metric(Rhythmic, lo_div, hi_div)
+    print_sim_metric(Phonemic, lo_div, hi_div)
 
     # rank similarities
     print("rankings")
-    print_ranking(RhythmicDiversity, ["I was wrong"], lo_div + hi_div)
-    # print_ranking(PhonemicDiversity, "burn big planets", lo_div + hi_div)
+    print_ranking(Rhythmic, ["I was wrong"], lo_div + hi_div)
+    # print_ranking(Phonemic, "burn big planets", lo_div + hi_div)
 
     # (textdiv) ~\GitHub\TextDiversity\src>python -m textdiversity.text_diversities.phonological
\ No newline at end of file
